DialogProviderImpl class final

Implemented types

Constructors

DialogProviderImpl(GlobalKey<State<StatefulWidget>> _globalKey)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showCommonDialog(String description, ButtonTextsWithActions buttons) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited