onMapTap method
Called when a tap occurred unless a tap was handled by geo objects or map objects. param@ position absolute screen coordinates
Implementation
@override
void onMapTap(Map map, Point point) {}
Called when a tap occurred unless a tap was handled by geo objects or map objects. param@ position absolute screen coordinates
@override
void onMapTap(Map map, Point point) {}