NavigationLayerManagerImpl class final
- Implemented types
Constructors
Properties
- cameraMode ↔ CameraMode?
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isCameraFollowingMode
→ Stream<
bool> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedRoute → DrivingRoute?
-
no setteroverride
Methods
-
dispose(
) → void -
override
-
initIfNeeded(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited