NavigationManagerImpl class final

Implemented types
Available extensions

Constructors

Properties

areRoutesBuilt Stream<bool>
no setteroverride
currentRoute → ValueStream<DrivingRoute?>
no setteroverride
guidanceActive Stream<bool>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isGuidanceActive bool

Available on NavigationManager, provided by the IsGuidanceActive extension

no setter
location → ValueStream<Location?>
no setteroverride
roadFlags Stream<String>
no setteroverride
roadName Stream<String>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speedLimit → LocalizedValue?
no setteroverride
speedLimitsPolicy → SpeedLimitsPolicy
no setteroverride
speedLimitStatus → SpeedLimitStatus
no setteroverride
speedLimitTolerance double
no setteroverride

Methods

dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestRoutes(List<RequestPoint> points) → void
override
resetRoutes() → void
override
resume() → void
override
startGuidance(DrivingRoute route) → void
override
startListening() → void
override
stopGuidance() → void
override
suspend() → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited