DialogsFactory class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showCancelGuidanceDialog({required VoidCallback primaryAction}) → void
showPermissionRequestDialog({required String description, required VoidCallback primaryAction}) → void
showRequestPointDialog({required VoidCallback onToClicked, required VoidCallback onViaClicked, required VoidCallback onFromClicked}) → void
showRequestToPointDialog({required VoidCallback primaryAction}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited