MapInputManager class abstract interface

Implemented types
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
longTapActions Stream<Point>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMapLongTap(Map map, Point point) → void
Called when a long tap occurred.
inherited
onMapTap(Map map, Point point) → void
Called when a tap occurred unless a tap was handled by geo objects or map objects. param@ position absolute screen coordinates
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited