NavigationManager class abstract interface

Implemented types
Implementers
Available extensions

Properties

areRoutesBuilt Stream<bool>
no setter
currentRoute → ValueStream<DrivingRoute?>
no setter
guidanceActive Stream<bool>
no setter
hashCode int
The hash code for this object.
no setterinherited
isGuidanceActive bool

Available on NavigationManager, provided by the IsGuidanceActive extension

no setter
location → ValueStream<Location?>
no setterinherited
roadFlags Stream<String>
no setter
roadName Stream<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speedLimit → LocalizedValue?
no setter
speedLimitsPolicy → SpeedLimitsPolicy
no setter
speedLimitStatus → SpeedLimitStatus
no setter
speedLimitTolerance double
no setter

Methods

dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestRoutes(List<RequestPoint> points) → void
resetRoutes() → void
resume() → void
startGuidance(DrivingRoute route) → void
startListening() → void
inherited
stopGuidance() → void
suspend() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited