NavigationStyleManager class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

balloonImageProvider() → NavigationBalloonImageProvider
inherited
highlightStyleProvider() → HighlightStyleProvider
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPointStyleProvider() → NavigationRequestPointStyleProvider
inherited
routePinsStyleProvider() → NavigationRoutePinsStyleProvider
inherited
routeViewStyleProvider() → NavigationRouteViewStyleProvider
inherited
toString() String
A string representation of this object.
inherited
userPlacemarkStyleProvider() → NavigationUserPlacemarkStyleProvider
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited