MapInputManagerImpl class
final
Methods
-
dispose()
→ void
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onMapLongTap(Map map, Point point)
→ void
-
Called when a long tap occurred.
-
onMapTap(Map map, Point point)
→ void
-
Called when a tap occurred unless a tap was handled by geo objects or
map objects. param@ position absolute screen coordinates
-
toString()
→ String
-
A string representation of this object.
inherited