- Implemented types
-
- Implementers
Methods
-
dispose()
→ void
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onMapLongTap(Map map, Point point)
→ void
-
Called when a long tap occurred.
inherited
-
onMapTap(Map map, Point point)
→ void
-
Called when a tap occurred unless a tap was handled by geo objects or
map objects. param@ position absolute screen coordinates
inherited
-
toString()
→ String
-
A string representation of this object.
inherited