- Implemented types
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requestPoints
→ Stream<
List< RequestPoint> > -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetPoints(
) → void -
setFromPoint(
Point point) → void -
setToPoint(
Point point) → void -
setViaPoint(
Point point) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited